package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.ElecEqptType;

/**
 * 动力柜电器设备类型Service接口
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
public interface IElecEqptTypeService
{
    /**
     * 查询动力柜电器设备类型
     * 
     * @param id 动力柜电器设备类型主键
     * @return 动力柜电器设备类型
     */
     ElecEqptType selectElecEqptTypeById(Long id);

    /**
     * 查询动力柜电器设备类型列表
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 动力柜电器设备类型集合
     */
     List<ElecEqptType> selectElecEqptTypeList(ElecEqptType eleceqptType);

    /**
     * 新增动力柜电器设备类型
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 结果
     */
     int insertElecEqptType(ElecEqptType eleceqptType);

    /**
     * 修改动力柜电器设备类型
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 结果
     */
     int updateElecEqptType(ElecEqptType eleceqptType);

    /**
     * 批量删除动力柜电器设备类型
     * 
     * @param ids 需要删除的动力柜电器设备类型主键集合
     * @return 结果
     */
     int deleteElecEqptTypeByIds(Long[] ids);

    /**
     * 删除动力柜电器设备类型信息
     * 
     * @param id 动力柜电器设备类型主键
     * @return 结果
     */
     int deleteElecEqptTypeById(Long id);
}
